# django-temporary-permissions

<!--
[![Test](https://github.com/k-tech-italy/ktcalendars/actions/workflows/test.yml/badge.svg)](https://github.com/k-tech-italy/ktcalendars/actions/workflows/test.yml)
[![Lint](https://github.com/k-tech-italy/ktcalendars/actions/workflows/lint.yml/badge.svg)](https://github.com/k-tech-italy/ktcalendars/actions/workflows/lint.yml)
[![Documentation](https://github.com/k-tech-italy/ktcalendars/actions/workflows/docs.yml/badge.svg)](https://github.com/k-tech-italy/ktcalendars/actions/workflows/docs.yml)
[![codecov](https://codecov.io/github/k-tech-italy/ktcalendars/graph/badge.svg?token=BNXEW4JAYF)](https://codecov.io/github/k-tech-italy/ktcalendars)
[![security: bandit](https://img.shields.io/badge/security-bandit-yellow.svg)](https://github.com/PyCQA/bandit)
[![Pypi](https://badge.fury.io/py/ktcalendars.svg)](https://badge.fury.io/py/ktcalendars)
[![coverage](https://codecov.io/github/k-tech-italy/ktcalendars/coverage.svg?branch=develop)](https://codecov.io/github/k-tech-italy/ktcalendars?branch=develop)
-->


KTCalendar is a library providing utility classes for country-specific holiday-aware calendars and dates.


## Dependencies

* Python 3.10 or later


## Installation

* Install ktcalendars using your package manager of choice, e.g. Pip:
  ```bash
  pip install ktcalendars
  ```

## Bug reports and requests for enhancements

Please open an issue on the project's [issue tracker on GitHub](https://github.com/k-tech-italy/django_temporary_permissions/issues).

## Contributing to the project

See the [contribution guide](CONTRIBUTING.md).

## Licensing

All rights reserved.
